@@ -1,8 +1,11 @@
 from __future__ import print_function
+from pkg_resources import working_set
+import abc
 import collections
 import os
 import re
 import sys
+from .compat import add_metaclass
 
 
 Message = collections.namedtuple('Message',
@@ -12,15 +15,6 @@ EXTRACTORS = {}
 EXTENSIONS = {}
 
 
-def register_extractor(identifier, extensions):
-    def wrapper(func):
-        EXTRACTORS[identifier] = func
-        for extension in extensions:
-            EXTENSIONS[extension] = func
-        return func
-    return wrapper
-
-
 def get_extractor(filename):
     ext = os.path.splitext(filename)[1]
     return EXTENSIONS.get(ext)
@@ -116,3 +110,28 @@ def update_keywords(keywords, specs):
             print(e, file=sys.stderr)
             sys.exit(1)
         keywords[kw.function] = kw
+
+
+@add_metaclass(abc.ABCMeta)
+class Extractor(object):
+    def __init__(self, config=None):
+        self.config = config if config else {}
+
+    @abc.abstractproperty
+    def extensions(self):
+        NotImplemented()
+
+    @abc.abstractmethod
+    def __call__(self, filename, options):
+        NotImplemented()
+
+
+def register_extractors():
+    for entry_point in working_set.iter_entry_points('lingua.extractors'):
+        extractor = entry_point.load(require=True)
+        if not issubclass(extractor, Extractor):
+            raise ValueError(
+                u'Registered extractor must derive from ``Extractor``')
+        EXTRACTORS[entry_point.name] = extractor
+        for extension in extractor.extensions:
+            EXTENSIONS[extension] = extractor()
