@@ -3,7 +3,7 @@ from __future__ import print_function
 import collections
 import sys
 from xml.parsers import expat
-from . import register_extractor
+from . import Extractor
 from . import Message
 
 
@@ -12,7 +12,8 @@ def _open(filename):
     return open(filename, 'rb')
 
 
-class ZcmlExtractor(object):
+class ZCMLExtractor(Extractor):
+    extensions = ['.zcml']
     ATTRIBUTES = set(['title', 'description'])
 
     def __call__(self, filename, options):
@@ -53,9 +54,3 @@ class ZcmlExtractor(object):
     def EndElementHandler(self, name):
         if self.domainstack:
             self.domainstack.pop()
-
-
-@register_extractor('zcml', ['.zcml'])
-def extract_zcml(filename, options):
-    extractor = ZcmlExtractor()
-    return extractor(filename, options)
